@@ -7,6 +7,7 @@ module Api
 
     before_action :load_settings
     before_action :set_default_response_format, :authorize, :set_taxonomy
+    before_action :check_media_type
     before_action :assign_lone_taxonomies, :only => :create
     before_action :add_info_headers, :set_gettext_locale
     before_action :session_expiry, :update_activity_time
@@ -23,9 +24,9 @@ module Api
 
     rescue_from NoMethodError do |error|
       Foreman::Logging.exception("Action failed", error)
-      message = _("Internal Server Error: the server was unable to finish the request. ")
-      message << _("This may be caused by unavailability of some required service, incorrect API call or a server-side bug. ")
-      message << _("There may be more information in the server's logs.")
+      message = _("Internal Server Error: the server was unable to finish the request. " \
+        "This may be caused by unavailability of some required service, incorrect API call or a server-side bug. " \
+        "There may be more information in the server's logs.")
       render_error 'custom_error', :status => :internal_server_error, :locals => { :message => message }
     end
 
@@ -120,6 +121,12 @@ module Api
       true
     end
 
+    def check_media_type
+      if (request.post? || request.put?) && request.media_type != "application/json"
+        render_error(:unsupported_media_type, :status => :unsupported_media_type)
+      end
+    end
+
     protected
 
     def not_found(options = nil)
