@@ -4,7 +4,11 @@ Foreman::Application.routes.draw do
     # new v2 routes that point to v2
     scope "(:apiv)", :module => :v2, :defaults => {:apiv => 'v2'}, :apiv => /v2/, :constraints => ApiConstraints.new(:version => 2, :default => true) do
       match 'hosts/bulk', :to => 'hosts_bulk_actions#bulk_destroy', :via => [:delete]
+      put 'hosts/bulk/assign_organization', :to => 'hosts_bulk_actions#assign_organization'
+      put 'hosts/bulk/assign_location', :to => 'hosts_bulk_actions#assign_location'
       match 'hosts/bulk/build', :to => 'hosts_bulk_actions#build', :via => [:put]
+      match 'hosts/bulk/change_owner', :to => 'hosts_bulk_actions#change_owner', :via => [:put]
+      put 'hosts/bulk/disassociate', :to => 'hosts_bulk_actions#disassociate'
       match 'hosts/bulk/reassign_hostgroup', :to => 'hosts_bulk_actions#reassign_hostgroup', :via => [:put]
 
       resources :architectures, :except => [:new, :edit] do
@@ -218,6 +222,13 @@ Foreman::Application.routes.draw do
           resources :mail_notifications, :only => [:create, :destroy, :update]
           get 'mail_notifications', :to => 'mail_notifications#user_mail_notifications', :on => :member
           get 'extlogin', :to => 'users#extlogin', :on => :collection
+          delete 'registration_tokens', :to => 'registration_tokens#invalidate_jwt', :on => :member
+        end
+      end
+
+      resources :registration_tokens, :only => [:invalidate_jwt_tokens] do
+        collection do
+          delete '/', :action => :invalidate_jwt_tokens
         end
       end
 
@@ -244,7 +255,6 @@ Foreman::Application.routes.draw do
           get :available_folders, :on => :member
           get :available_flavors, :on => :member
           get :available_networks, :on => :member
-          get :available_vnic_profiles, :on => :member
           get :available_security_groups, :on => :member
           get :available_storage_domains, :on => :member
           get 'storage_domains/(:storage_domain_id)', :to => 'compute_resources#storage_domain', :on => :member
